Trait diem_sdk::crypto::traits::Length [−][src]
The serialized length of the data that enables macro derived serialization and deserialization.
The serialized length of the data that enables macro derived serialization and deserialization.